@@ -39,11 +39,11 @@ sub add_libpath {
 }
 
 our @EXPORT = qw(tora_call_func
-    tora_op_equal tora_op_ne
+    tora_op_eq tora_op_ne
     tora_op_lt tora_op_gt
     tora_op_le tora_op_ge
     tora_make_range
-    tora_op_add tora_op_div tora_op_mul
+    tora_op_add tora_op_div tora_op_mul tora_op_pow
     tora_get_item
     tora_deref
     tora_use
@@ -191,7 +191,7 @@ sub __tora_get_method_fallback {
     croak "Unknown method named $methname in $klass_name";
 }
 
-sub tora_op_equal {
+sub tora_op_eq {
     my ($lhs, $rhs) = @_;
 
     # check undef
@@ -348,6 +348,16 @@ sub tora_op_mul {
     }
 }
 
+sub tora_op_pow {
+    my ($lhs, $rhs) = @_;
+    my $flags = B::svref_2object(\$lhs)->FLAGS;
+    if ($flags & (B::SVp_IOK | B::SVp_NOK) and !( $flags & B::SVp_POK )) {
+        return $lhs ** $rhs;
+    } else {
+        ...
+    }
+}
+
 sub tora_op_div {
     my ($lhs, $rhs) = @_;
     my $flags = B::svref_2object(\$lhs)->FLAGS;
